================
Related software
================

The MinimalModbus package is intended for easy-to-use communication with 
instruments using the Modbus (RTU and ASCII) protocol. 
There are a few other Python packages for Modbus protocol implementation. 
For more advanced use, you should consider using one of these:

pyModbus 
    From https://github.com/riptideio/pymodbus: 'Pymodbus is a full Modbus 
    protocol implementation using twisted for its asynchronous communications core.'

modbus-tk
    From https://github.com/ljean/modbus-tk: 'Make possible to write modbus 
    TCP and RTU master and slave mainly for testing purpose. It is shipped with 
    slave simulator and a master with a web-based hmi. It is a full-stack 
    implementation and as a consequence could also be used on real-world project.'

umodbus
    From https://github.com/AdvancedClimateSystems/umodbus/: 'uModbus or (μModbus) is a pure 
    Python implementation of the Modbus protocol as described in the MODBUS 
    Application Protocol Specification V1.1b3. uModbus implements both a Modbus 
    client (both TCP and RTU) and a Modbus server (both TCP and RTU).'

EasyModbusTCP/UDP/RTU Python
    From https://sourceforge.net/projects/easymodbustcp-udp-rtu-python/: 'EasyModbusTCP 
    library is available for .NET / Java / and Python. Same Handling for different 
    implementations and different plattforms.'

pyModbusTCP
    From https://github.com/sourceperl/pyModbusTCP: 'A simple Modbus/TCP library for Python'

pylibmodbus
    From https://github.com/stephane/pylibmodbus: 'Python Interface for libmodbus
    written with CFFI (Python 2 and Python 3) '
